# -*- coding: utf-8 -*-
# Copyright 2009-2016, Red Hat, Inc.
# License: GPL-2.0+ <http://spdx.org/licenses/GPL-2.0+>
# See the LICENSE file for more details on Licensing

from libtaskotron.directives import shell_directive
from libtaskotron.exceptions import TaskotronDirectiveError

import os
import pytest
import mock

OUTPUT = "Piko a Rybi prsty"
PATH = os.path.realpath(__file__)


@pytest.mark.usefixtures("setup")
class TestCheckCommand(object):

    @pytest.fixture
    def setup(self, monkeypatch):
        self.shell_dir = shell_directive.ShellDirective()
        self.mock_check_output = mock.Mock()
        monkeypatch.setattr(shell_directive, 'check_output', self.mock_check_output)
        self.arg_data = {'task': PATH}

    def test_a_list(self):
        test_params = ['cmd.exe']
        self.mock_check_output.return_value = OUTPUT

        output = self.shell_dir.process(test_params, self.arg_data)

        assert output == OUTPUT

    def test_not_a_list(self, monkeypatch):
        test_params = {'a dict': 'instead of a list'}

        with pytest.raises(TaskotronDirectiveError):
            self.shell_dir.process(test_params, self.arg_data)

        assert not self.mock_check_output.called

    def test_cmd_not_a_str(self, monkeypatch):
        test_params = [False]

        with pytest.raises(TaskotronDirectiveError):
            self.shell_dir.process(test_params, self.arg_data)

        assert not self.mock_check_output.called

    def test_cmd_not_a_list_of_strs(self, monkeypatch):
        test_params = [['echo', False]]

        with pytest.raises(TaskotronDirectiveError):
            self.shell_dir.process(test_params, self.arg_data)

        assert not self.mock_check_output.called
